# January 12, 2024 - Version 1.4.1


## Summary

---

**✈️ Market beta functions are newly added!**

Please update PrismStudio via

```python
pip install prismstudio --upgrade
```

or

```python
pip install prismstudio==1.4.1
```


If you prefer to use Anaconda, please install PrismStudio using command below

```bash
conda config --add channels conda-forge
conda install -c prism39 prismstudio
```

## January 12, 2024 -
PrismStudio 1.4.1

---

### Market Beta Function Added
PrismStudio now includes [Beta Component](<#prism.market.beta>)



